==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_functions/gridresult/GRID_GRIDRESULT.java <==

package net.datastream.schemas.mp_functions.gridresult;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_functions.gridtoolbar.TOOLBAR;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridResult}DATASPY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridToolbar}TOOLBAR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridResult}GRID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dataspy",
    "toolbar",
    "grid"
})
@XmlRootElement(name = "GRID_GRIDRESULT")
public class GRID_GRIDRESULT {

    @XmlElement(name = "DATASPY")
    protected DATASPY dataspy;
    @XmlElement(name = "TOOLBAR", namespace = "http://schemas.datastream.net/MP_functions/GridToolbar")
    protected TOOLBAR toolbar;
    @XmlElement(name = "GRID")
    protected GRID grid;

    /**
     * Obtient la valeur de la propriété dataspy.
     * 
     * @return
     *     possible object is
     *     {@link DATASPY }
     *     
     */
    public DATASPY getDATASPY() {
        return dataspy;
    }

    /**
     * Définit la valeur de la propriété dataspy.
     * 
     * @param value
     *     allowed object is
     *     {@link DATASPY }
     *     
     */
    public void setDATASPY(DATASPY value) {
        this.dataspy = value;
    }

    /**
     * Obtient la valeur de la propriété toolbar.
     * 
     * @return
     *     possible object is
     *     {@link TOOLBAR }
     *     
     */
    public TOOLBAR getTOOLBAR() {
        return toolbar;
    }

    /**
     * Définit la valeur de la propriété toolbar.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLBAR }
     *     
     */
    public void setTOOLBAR(TOOLBAR value) {
        this.toolbar = value;
    }

    /**
     * Obtient la valeur de la propriété grid.
     * 
     * @return
     *     possible object is
     *     {@link GRID }
     *     
     */
    public GRID getGRID() {
        return grid;
    }

    /**
     * Définit la valeur de la propriété grid.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID }
     *     
     */
    public void setGRID(GRID value) {
        this.grid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_functions/gridresult/GRID_GRIDRESULT.java <==

package net.datastream.schemas.mp_functions.gridresult;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_functions.gridtoolbar.TOOLBAR;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridResult}DATASPY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridToolbar}TOOLBAR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridResult}GRID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dataspy",
    "toolbar",
    "grid"
})
@XmlRootElement(name = "GRID_GRIDRESULT")
public class GRID_GRIDRESULT {

    @XmlElement(name = "DATASPY")
    protected DATASPY dataspy;
    @XmlElement(name = "TOOLBAR", namespace = "http://schemas.datastream.net/MP_functions/GridToolbar")
    protected TOOLBAR toolbar;
    @XmlElement(name = "GRID")
    protected GRID grid;

    /**
     * Gets the value of the dataspy property.
     * 
     * @return
     *     possible object is
     *     {@link DATASPY }
     *     
     */
    public DATASPY getDATASPY() {
        return dataspy;
    }

    /**
     * Sets the value of the dataspy property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATASPY }
     *     
     */
    public void setDATASPY(DATASPY value) {
        this.dataspy = value;
    }

    /**
     * Gets the value of the toolbar property.
     * 
     * @return
     *     possible object is
     *     {@link TOOLBAR }
     *     
     */
    public TOOLBAR getTOOLBAR() {
        return toolbar;
    }

    /**
     * Sets the value of the toolbar property.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLBAR }
     *     
     */
    public void setTOOLBAR(TOOLBAR value) {
        this.toolbar = value;
    }

    /**
     * Gets the value of the grid property.
     * 
     * @return
     *     possible object is
     *     {@link GRID }
     *     
     */
    public GRID getGRID() {
        return grid;
    }

    /**
     * Sets the value of the grid property.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID }
     *     
     */
    public void setGRID(GRID value) {
        this.grid = value;
    }

}
